@@ -11,7 +11,7 @@ from sqlalchemy.orm import mapper
 
 from rfc3339 import rfc3339
 
-DBSession = scoped_session(sessionmaker())
+DBSession = scoped_session(sessionmaker(autocommit=True))
 metadata = MetaData()
 
 class Comment(object):
